@@ -11,7 +11,7 @@
 
 from __future__ import absolute_import
 
-__version__ = '0.1.14'
+__version__ = '0.1.15'
 
 import hashlib
 import random
@@ -235,7 +235,7 @@ class SeaSurf(object):
         return the response unaltered. Bound to the Flask `after_request`
         decorator.'''
 
-        if getattr(g, self._csrf_name) is None:
+        if getattr(g, self._csrf_name, None) is None:
             return response
 
         if not getattr(g, '_csrf_used', False):
